@@ -12,9 +12,10 @@ def callback():
 
 
 @app.command()
-def initialize():
+def initialize(name: str):
     """
     Setup Git-Leaks
+    :type name: str The user's name
     """
-    typer.echo("Git-Leaks setup successfully, we can all go home")
+    typer.echo(f"Git-Leaks setup successfully for {name}, we can all go home")
 
